@@ -9,7 +9,7 @@ import prompt_toolkit
 from prompt_toolkit.buffer import Buffer
 from prompt_toolkit.key_binding import KeyPressEvent
 from prompt_toolkit.key_binding.bindings import named_commands as nc
-from prompt_toolkit.auto_suggest import AutoSuggestFromHistory, Suggestion, AutoSuggest
+from prompt_toolkit.auto_suggest import AutoSuggestFromHistory, Suggestion
 from prompt_toolkit.document import Document
 from prompt_toolkit.history import History
 from prompt_toolkit.shortcuts import PromptSession
@@ -103,9 +103,6 @@ class AppendAutoSuggestionInAnyLine(Processor):
         if len(suggestions) == 0:
             return noop("noop: no suggestions")
 
-        suggestions_longer_than_buffer: bool = (
-            len(suggestions) + ti.document.cursor_position_row > ti.document.line_count
-        )
         if prompt_toolkit.VERSION < (3, 0, 49):
             if len(suggestions) > 1 and prompt_toolkit.VERSION < (3, 0, 49):
                 if ti.lineno == ti.document.cursor_position_row:
@@ -132,7 +129,6 @@ class AppendAutoSuggestionInAnyLine(Processor):
             return Transformation(fragments=ti.fragments + [(self.style, suggestion)])
         if is_last_line:
             if delta < len(suggestions):
-                extra = f"; {len(suggestions) - delta} line(s) hidden"
                 suggestion = f"… rest of suggestion ({len(suggestions) - delta} lines) and code hidden"
                 return Transformation([(self.style, suggestion)])
 
@@ -171,7 +167,7 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
     _connected_apps: list[PromptSession]
 
     # handle to the currently running llm task that appends suggestions to the
-    # current buffer; we keep a handle to it in order to cancell it when there is a cursor movement, or
+    # current buffer; we keep a handle to it in order to cancel it when there is a cursor movement, or
     # another request.
     _llm_task: asyncio.Task | None = None
 
@@ -185,6 +181,7 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
         self.skip_lines = 0
         self._connected_apps = []
         self._llm_provider = None
+        self._request_number = 0
 
     def reset_history_position(self, _: Buffer) -> None:
         self.skip_lines = 0
@@ -306,7 +303,7 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
 
     def _cancel_running_llm_task(self) -> None:
         """
-        Try to cancell the currently running llm_task if exists, and set it to None.
+        Try to cancel the currently running llm_task if exists, and set it to None.
         """
         if self._llm_task is not None:
             if self._llm_task.done():
@@ -350,10 +347,10 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
             try:
                 await self._trigger_llm_core(buffer)
             except Exception as e:
-                get_ipython().log.error("error")
+                get_ipython().log.error("error %s", e)
                 raise
 
-        # here we need a cancellable task so we can't just await the error catched
+        # here we need a cancellable task so we can't just await the error caught
         self._llm_task = asyncio.create_task(error_catcher(buffer))
         await self._llm_task
 
@@ -365,9 +362,8 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
         provider to stream it's response back to us iteratively setting it as
         the suggestion on the current buffer.
 
-        Unlike with JupyterAi, as we do not have multiple cell, the cell number
-        is always set to `0`, note that we _could_ set it to a new number each
-        time and ignore threply from past numbers.
+        Unlike with JupyterAi, as we do not have multiple cell, the cell id
+        is always set to `None`.
 
         We set the prefix to the current cell content, but could also inset the
         rest of the history or even just the non-fail history.
@@ -389,10 +385,12 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
 
         hm = buffer.history.shell.history_manager
         prefix = self._llm_prefixer(hm)
-        print(prefix)
+        get_ipython().log.debug("prefix: %s", prefix)
 
+        self._request_number += 1
+        request_number = self._request_number
         request = jai_models.InlineCompletionRequest(
-            number=0,
+            number=request_number,
             prefix=prefix + buffer.document.text,
             suffix="",
             mime="text/x-python",
@@ -405,6 +403,9 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
         async for reply_and_chunks in self._llm_provider.stream_inline_completions(
             request
         ):
+            if self._request_number != request_number:
+                # If a new suggestion was requested, skip processing this one.
+                return
             if isinstance(reply_and_chunks, jai_models.InlineCompletionReply):
                 if len(reply_and_chunks.list.items) > 1:
                     raise ValueError(
@@ -427,7 +428,7 @@ async def llm_autosuggestion(event: KeyPressEvent):
     This will first make sure that the current buffer have _MIN_LINES (7)
     available lines to insert the LLM completion
 
-    Provisional as of 8.32, may change without warnigns
+    Provisional as of 8.32, may change without warnings
 
     """
     _MIN_LINES = 5
